@@ -1,7 +1,7 @@
 test2x2 = function(bedata, Var)
 {
   if(!assert(bedata)) {
-    cat("\n Subject count should be balanced!\n");
+    cat("\n Drop-outed subjects should not be included!\n");
     return(NULL);
   }
 
@@ -48,7 +48,7 @@ test2x2 = function(bedata, Var)
   SSperiod  = 2*n1*n2/(n1+n2)*(Y.21 + Y.22 - Y.11 - Y.12)^2 / 4
   SSdrug    = 2*n1*n2/(n1+n2)*(Y.21 + Y.12 - Y.11 - Y.22)^2 / 4
 
-  SSintra  = 2*(sum((di1 - d.1)^2) + sum((di2 - d.2)^2))
+  SSintra   = 2*(sum((di1 - d.1)^2) + sum((di2 - d.2)^2))
 #  SSmodel = SStotal - SSintra
 
   Source = c("SUBJECT", "GROUP", "SUBJECT(GROUP)", "PERIOD", "DRUG", "ERROR", "TOTAL");
@@ -65,8 +65,9 @@ test2x2 = function(bedata, Var)
   p  = c(p1, p2, p3, p4, p5, NA, NA)
   Fv[6] = Fv[7] = MS[7] = NA
 
-  ANOVA = cbind(SS, DF, MS, Fv, p)
-  dimnames(ANOVA) = list(Source,c("SS", "DF", "MS", "F", "p"))
+  ANOVA = cbind(DF, SS, MS, Fv, p)
+  dimnames(ANOVA) = list(Source, c("Df", "Sum Sq", "Mean Sq", "F value", "Pr(>F)"))
+  class(ANOVA) = "anova"
 
   pe = mu.t - mu.r
   se = sqrt(mse/2 * (1/n1 + 1/n2))   # See pp 62-63 of Chow & Liu
